<?php
/**
*Plugin Name: Category Buttons
*Description: A simple plugin that enables you to add custom category buttons to all shop pages and category pages.
*Version: 1.0.3
*Author: Ryvenia
*Author URI: https://ryvenia.sk/
*License: GPL2
*License URI: https://www.gnu.org/licenses/gpl-2.0.html
*Text Domain: category-buttons
*Domain Path: /languages
*/
// Add Settings button
function ryvenia_load_textdomain( $mofile, $domain ) {
    if ( 'category-buttons' === $domain && false !== strpos( $mofile, WP_LANG_DIR . '/plugins/' ) ) {
        $locale = apply_filters( 'plugin_locale', determine_locale(), $domain );
        $mofile = WP_PLUGIN_DIR . '/' . dirname( plugin_basename( __FILE__ ) ) . '/languages/' . $domain . '-' . $locale . '.mo';
    }
    return $mofile;
}
add_filter( 'load_textdomain_mofile', 'ryvenia_load_textdomain', 10, 2 );

add_action( 'init', 'ryvenia_load_text_domain' );
 
function ryvenia_load_text_domain() {
    load_plugin_textdomain( 'category-buttons', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}
add_filter('plugin_action_links_'.plugin_basename(__FILE__), 'ryvenia_add_plugin_settings_link');

function ryvenia_add_plugin_settings_link( $links ) {
    $url = admin_url()."admin.php?page=settings";
    $settings_link = '<a href="'.esc_url( $url ).'">'.esc_html( __('Settings') ).'</a>';
    $links[] = $settings_link;
    return $links;
}
// Add Meta
add_filter( 'plugin_row_meta', 'ryvenia_plugin_meta_links', 10, 2 );
function ryvenia_plugin_meta_links( $links, $file ) {
    if ( strpos( $file, basename(__FILE__) ) ) {
        $links[] = '<a href="mailto:ryvenia@ryvenia.com" target="_blank" title="Support"> Support </a>';
    }
    return $links;
}
// Check if WooCommerce is active
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
} else {
    add_action( 'admin_notices', function(){
        $plugin_data = get_plugin_data( __FILE__ );
        $plugin_name = $plugin_data['Name'];
        echo wp_kses_post('<div id="message" class="error notice is-dismissible"><p><b>'.esc_html__( 'Plugin Category Buttons requires WooCommerce. Please install and activate it first.', 'category-buttons' ).'</b></p></div>');
	} );
	return;
}
// Set default values
function ryvenia_activation_actions(){
    do_action( 'ryvenia_extension_activation' );
}
register_activation_hook( __FILE__, 'ryvenia_activation_actions' );
// Set default values here
function ryvenia_default_options(){
    $default = array(
        'display_in_store_0'     => 'display-in-store',
        'store_display_style_1'   => 'with-title-description',
        'shortcode_display_style_2'   => 'with-title-description',
        'images_5'   => 'display-images',
        'columns_desktop_0'   => '4',
        'columns_tablet_1'   => '3',
        'columns_mobile_2'   => '1',
        'background_color_3'   => '#ffffff',
        'text_color_4'   => '#000000',
        'border_color_6'   => '#ebebeb',
        'border_radius_5'   => '4px',
        'title_font_size_7'   => '1.75rem',
        'description_font_size_8'   => '.875rem',
        'buttons_font_size_9'   => '.875rem',
        'custom_css_10'   => '',
        'custom_title_3'   => '',
        'custom_description_4'   => '',
    );
    $check = get_option( 'woocommerce_category_buttons_option_name' );
    if ($check['display_in_store_0'] == '') {
    //if ($check['display_in_store_0'] != 'display-in-store' || $check['display_in_store_0'] != 'hide-in-store') {
        update_option( 'woocommerce_category_buttons_option_name', $default );
        update_option( 'ryvenia_style_settings_option_name', $default );
    }
}
add_action( 'ryvenia_extension_activation', 'ryvenia_default_options' );
// Add admin section
require_once plugin_dir_path(__FILE__) . 'wct-settings.php';
require_once plugin_dir_path(__FILE__) . 'style-settings.php';
add_action('wp_head', 'ryvenia_buttons_style');
function ryvenia_buttons_style(){
require_once( plugin_dir_path(__FILE__) . 'includes/cat-menu-style.php' );
}