<?php
add_filter( 'load_textdomain_mofile', 'ryvenia_load_textdomain', 10, 2 );

add_action( 'init', 'ryvenia_load_text_domain' );
class WoocommerceCategoryButtons {
	private $woocommerce_category_buttons_options;

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'woocommerce_category_buttons_add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'woocommerce_category_buttons_page_init' ) );
	}

	public function woocommerce_category_buttons_add_plugin_page() {
		add_menu_page(
			esc_html__( 'Category Buttons', 'category-buttons' ), // page_title
			esc_html__( 'Category Buttons', 'category-buttons' ), // menu_title
			'', // capability
			'woocommerce-category-buttons', // menu_slug
			array( $this, 'woocommerce_category_buttons_create_admin_page' ), // function
			plugin_dir_url( __FILE__ ) . 'includes/icon.png', // icon_url
			2 // position
		);
        add_submenu_page(
            'woocommerce-category-buttons',
            esc_html__( 'Settings', 'category-buttons' ), //page title
            esc_html__( 'Settings', 'category-buttons' ), //menu title
            'manage_options', //capability,
            'settings',//menu slug
            array( $this, 'woocommerce_category_buttons_create_admin_page' ) // function
        );
	}

	public function woocommerce_category_buttons_create_admin_page() {
		$this->woocommerce_category_buttons_options = get_option( 'woocommerce_category_buttons_option_name' ); ?>

		<div class="wrap">
            <?php echo wp_kses_post("<h2>".esc_html__( 'Woocommerce Category Buttons', 'category-buttons' )."</h2>"); ?>
            <?php echo wp_kses_post("<p>".esc_html__( 'Thanks for using our plugin. For support or bug reports please email us at ryvenia@ryvenia.com', 'category-buttons' )."</p>"); ?>
			<?php settings_errors(); ?>

			<form method="post" action="options.php">
				<?php
					settings_fields( 'woocommerce_category_buttons_option_group' );
					do_settings_sections( 'woocommerce-category-buttons-admin' );
                    echo wp_kses_post("<h2>".esc_html__( 'Shortcode Settings', 'category-buttons' )."</h2>");
                    echo wp_kses_post("<h3>".esc_html__( 'How to use?', 'category-buttons' )."</h3>");
                    echo wp_kses_post("<p>".esc_html__( 'Use shortcode', 'category-buttons' )." <b>[woocb]</b> ".esc_html__( 'You can use it in any short code supported environment from Gutenberg, Elementor or other page builders.', 'category-buttons' )."</p>");
                    do_settings_sections( 'woocommerce-category-buttons-admin-shortcode' );
                    echo wp_kses_post("<h2>".esc_html__( 'Custom Settings', 'category-buttons' )."</h2>");
                    echo wp_kses_post("<p>".esc_html__( "By adding a custom title or description, you'll overwrite the category content with your text written here. It is global and will overwrite all titles and descriptions if used in this plugin.", 'category-buttons' )."</p>");
                    do_settings_sections( 'woocommerce-category-buttons-admin-custom-settings' );
                    do_settings_sections( 'woocommerce-category-buttons-admin-image-settings' );
					submit_button();
				?>
			</form>
		</div>
	<?php }

public function woocommerce_category_buttons_page_init() {
    register_setting(
        'woocommerce_category_buttons_option_group', // option_group
        'woocommerce_category_buttons_option_name', // option_name
        array( $this, 'woocommerce_category_buttons_sanitize' ) // sanitize_callback
    );

    add_settings_section(
        'woocommerce_category_buttons_setting_section', // id
        esc_html__('Store Setting', 'category-buttons'), // title
        array( $this, 'woocommerce_category_buttons_section_info' ), // callback
        'woocommerce-category-buttons-admin' // page
    );

    add_settings_section(
        'woocommerce_category_buttons_setting_section', // id
        '', // title
        array( $this, 'woocommerce_category_buttons_section_info' ), // callback
        'woocommerce-category-buttons-admin-shortcode' // page
    );

    add_settings_section(
        'woocommerce_category_buttons_setting_section', // id
        '', // title
        array( $this, 'woocommerce_category_buttons_section_info' ), // callback
        'woocommerce-category-buttons-admin-custom-settings' // page
    );

    add_settings_section(
        'woocommerce_category_buttons_setting_section', // id
        esc_html__('Image Settings', 'category-buttons'), // title
        array( $this, 'woocommerce_category_buttons_section_info' ), // callback
        'woocommerce-category-buttons-admin-image-settings' // page
    );

    add_settings_field(
        'display_in_store_0', // id
        esc_html__('Display in store', 'category-buttons'), // title
        array( $this, 'display_in_store_0_callback' ), // callback
        'woocommerce-category-buttons-admin', // page
        'woocommerce_category_buttons_setting_section' // section
    );

    add_settings_field(
        'store_display_style_1', // id
        esc_html__('Store display style', 'category-buttons'), // title
        array( $this, 'store_display_style_1_callback' ), // callback
        'woocommerce-category-buttons-admin', // page
        'woocommerce_category_buttons_setting_section' // section
    );

    add_settings_field(
        'shortcode_display_style_2', // id
        esc_html__('Shortcode display style', 'category-buttons'), // title
        array( $this, 'shortcode_display_style_2_callback' ), // callback
        'woocommerce-category-buttons-admin-shortcode', // page
        'woocommerce_category_buttons_setting_section' // section
    );

    add_settings_field(
        'custom_title_3', // id
        esc_html__('Custom title', 'category-buttons'), // title
        array( $this, 'custom_title_3_callback' ), // callback
        'woocommerce-category-buttons-admin-custom-settings', // page
        'woocommerce_category_buttons_setting_section' // section
    );

    add_settings_field(
        'custom_description_4', // id
        esc_html__('Custom description', 'category-buttons'), // title
        array( $this, 'custom_description_4_callback' ), // callback
        'woocommerce-category-buttons-admin-custom-settings', // page
        'woocommerce_category_buttons_setting_section' // section
    );

    add_settings_field(
        'images_5', // id
        esc_html__('Images', 'category-buttons'), // title
        array( $this, 'images_5_callback' ), // callback
        'woocommerce-category-buttons-admin-image-settings', // page
        'woocommerce_category_buttons_setting_section' // section
    );
}

public function woocommerce_category_buttons_sanitize($input) {
    $sanitary_values = array();
    if ( isset( $input['display_in_store_0'] ) ) {
        $sanitary_values['display_in_store_0'] = sanitize_text_field($input['display_in_store_0']);
    }

    if ( isset( $input['store_display_style_1'] ) ) {
        $sanitary_values['store_display_style_1'] = sanitize_text_field($input['store_display_style_1']);
    }

    if ( isset( $input['shortcode_display_style_2'] ) ) {
        $sanitary_values['shortcode_display_style_2'] = sanitize_text_field($input['shortcode_display_style_2']);
    }

    if ( isset( $input['custom_title_3'] ) ) {
        $sanitary_values['custom_title_3'] = sanitize_text_field( $input['custom_title_3'] );
    }

    if ( isset( $input['custom_description_4'] ) ) {
        $sanitary_values['custom_description_4'] = sanitize_textarea_field( $input['custom_description_4'] );
    }

    if ( isset( $input['images_5'] ) ) {
        $sanitary_values['images_5'] = sanitize_text_field($input['images_5']);
    }

    return $sanitary_values;
}

public function woocommerce_category_buttons_section_info() {
    
}

public function display_in_store_0_callback() {
    ?> <select name="woocommerce_category_buttons_option_name[display_in_store_0]" id="display_in_store_0">
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['display_in_store_0'] ) && $this->woocommerce_category_buttons_options['display_in_store_0'] === 'display-in-store') ? 'selected' : '' ; ?>
        <option value="display-in-store" <?php echo $selected; ?>><?php _e('Display in store', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['display_in_store_0'] ) && $this->woocommerce_category_buttons_options['display_in_store_0'] === 'hide-in-store') ? 'selected' : '' ; ?>
        <option value="hide-in-store" <?php echo $selected; ?>><?php _e('Hide in store', 'category-buttons') ?></option>
    </select> <?php
}

public function store_display_style_1_callback() {
    ?> <select name="woocommerce_category_buttons_option_name[store_display_style_1]" id="store_display_style_1">
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['store_display_style_1'] ) && $this->woocommerce_category_buttons_options['store_display_style_1'] === 'with-title-description') ? 'selected' : '' ; ?>
        <option value="with-title-description" <?php echo $selected; ?>><?php _e('With title and description', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['store_display_style_1'] ) && $this->woocommerce_category_buttons_options['store_display_style_1'] === 'with-title') ? 'selected' : '' ; ?>
        <option value="with-title" <?php echo $selected; ?>><?php _e('With title', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['store_display_style_1'] ) && $this->woocommerce_category_buttons_options['store_display_style_1'] === 'with-description') ? 'selected' : '' ; ?>
        <option value="with-description" <?php echo $selected; ?>><?php _e('With description', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['store_display_style_1'] ) && $this->woocommerce_category_buttons_options['store_display_style_1'] === 'without-title-description') ? 'selected' : '' ; ?>
        <option value="without-title-description" <?php echo $selected; ?>><?php _e('Without title and description', 'category-buttons') ?></option>
    </select> <?php
}

public function shortcode_display_style_2_callback() {
    ?> <select name="woocommerce_category_buttons_option_name[shortcode_display_style_2]" id="shortcode_display_style_2">
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['shortcode_display_style_2'] ) && $this->woocommerce_category_buttons_options['shortcode_display_style_2'] === 'with-title-description') ? 'selected' : '' ; ?>
        <option value="with-title-description" <?php echo $selected; ?>><?php _e('With title and description', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['shortcode_display_style_2'] ) && $this->woocommerce_category_buttons_options['shortcode_display_style_2'] === 'with-title') ? 'selected' : '' ; ?>
        <option value="with-title" <?php echo $selected; ?>><?php _e('With title', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['shortcode_display_style_2'] ) && $this->woocommerce_category_buttons_options['shortcode_display_style_2'] === 'with-description') ? 'selected' : '' ; ?>
        <option value="with-description" <?php echo $selected; ?>><?php _e('With description', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['shortcode_display_style_2'] ) && $this->woocommerce_category_buttons_options['shortcode_display_style_2'] === 'without-title-description') ? 'selected' : '' ; ?>
        <option value="without-title-description" <?php echo $selected; ?>><?php _e('Without title and description', 'category-buttons') ?></option>
    </select> <?php
}

public function custom_title_3_callback() {
    printf(
        '<input class="regular-text" type="text" name="woocommerce_category_buttons_option_name[custom_title_3]" id="custom_title_3" value="%s">',
        isset( $this->woocommerce_category_buttons_options['custom_title_3'] ) ? esc_attr( $this->woocommerce_category_buttons_options['custom_title_3']) : ''
    );
}

public function custom_description_4_callback() {
    printf(
        '<textarea class="large-text" rows="5" name="woocommerce_category_buttons_option_name[custom_description_4]" id="custom_description_4">%s</textarea>',
        isset( $this->woocommerce_category_buttons_options['custom_description_4'] ) ? esc_attr( $this->woocommerce_category_buttons_options['custom_description_4']) : ''
    );
}

public function images_5_callback() {
    ?> <select name="woocommerce_category_buttons_option_name[images_5]" id="images_5">
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['images_5'] ) && $this->woocommerce_category_buttons_options['images_5'] === 'display-images') ? 'selected' : '' ; ?>
        <option value="display-images" <?php echo $selected; ?>><?php _e('Display images', 'category-buttons') ?></option>
        <?php $selected = (isset( $this->woocommerce_category_buttons_options['images_5'] ) && $this->woocommerce_category_buttons_options['images_5'] === 'hide-images') ? 'selected' : '' ; ?>
        <option value="hide-images" <?php echo $selected; ?>><?php _e('Hide images', 'category-buttons') ?></option>
    </select> <?php
}

}
if ( is_admin() )
$woocommerce_category_buttons = new WoocommerceCategoryButtons();

$woocommerce_category_buttons_options = get_option( 'woocommerce_category_buttons_option_name' ); // Array of All Options
$display_in_store_0 = $woocommerce_category_buttons_options['display_in_store_0']; // Display in store
$store_display_style_1 = $woocommerce_category_buttons_options['store_display_style_1']; // Store display style
$shortcode_display_style_2 = $woocommerce_category_buttons_options['shortcode_display_style_2']; // Shortcode display style
//$custom_title_3 = $woocommerce_category_buttons_options['custom_title_3']; // Custom title
//$custom_description_4 = $woocommerce_category_buttons_options['custom_description_4']; // Custom description
$images_5 = $woocommerce_category_buttons_options['images_5']; // Images

if( $display_in_store_0 == "display-in-store" ){
    require_once plugin_dir_path(__FILE__) . 'includes/wcb.php';
} 